## CHANGELOG

### 0.11.2 - 2020-09-03

 - Fix wait_call function

### 0.11.1 - 2020-09-03

 - Improve caller

### 0.11.0 - 2020-09-03

 - Create ramp-up feature

### 0.10.5 - 2020-05-08

 - Fix tests for new apidaora version

### 0.10.4 - 2020-04-14

 - Update tests for new apidaora version

### 0.10.3 - 2020-04-14

 - Update tests for new apidaora version

### 0.10.2 - 2020-04-13

 - Fix new apidaora interface

### 0.10.1 - 2020-04-12

 - Fix tests for new apidaora version

### 0.10.0 - 2020-03-06

 - Move the Call class to a isolated module

### 0.9.0 - 2020-03-06

 - Improve Caller to do synchronous calls when the calls are in blocks

### 0.8.0 - 2020-03-06

 - Support body on calls

 - Fix run calls with python script

### 0.7.0 - 2020-03-06

 - Add support to run the calls with a python script

### 0.6.0 - 2020-03-06

 - Add support for make calls in block

### 0.5.2 - 2020-02-27

 - Update requirements

 - Fix config class

### 0.5.1 - 2020-02-27

 - Fix rps_per_node calculation

### 0.5.0 - 2019-11-08

 - Add status endpoint

 - Fix caller inputs management

### 0.4.2 - 2019-11-08

 - Fix background caller, but needs gunicorn

### 0.4.1 - 2019-11-07

 - Skip errors on background caller

### 0.4.0 - 2019-11-07

 - Skip errors and count them

### 0.3.0 - 2019-11-07

 - Add support for multiple workers

### 0.2.1 - 2019-11-07

 - Fix requirements

### 0.2.0 - 2019-11-07

 - Add support for distribution calls

### 0.1.0 - 2019-11-04

 - Create first version of the application
